@@ -4,7 +4,7 @@
 ## Copyright (C) 2002 - 2009 Dirk Eddelbuettel <edd@debian.org>
 ## Copyright (C) 2009        Khanh Nguyen <knguyen@cs.umb.edu>
 ##
-## $Id: asian.R 277 2010-08-02 16:45:46Z edd $
+## $Id: asian.R 293 2010-08-07 15:56:13Z edd $
 ##
 ## This file is part of the RQuantLib library for GNU R.
 ## It is made available under the terms of the GNU General Public
@@ -41,7 +41,7 @@ AsianOption.default <- function(averageType, type, underlying, strike, dividendY
             maturity <- 1.0             # actually unused for arithmetic option case
         }
     }
-    val <- .Call("QL_AsianOption",
+    val <- .Call("AsianOption",
                  list(averageType=as.character(averageType),
                       type=as.character(type),
                       underlying=as.double(underlying),
